<?PHP
/***************************************************************************

Plugin Name:  Dashboard: Technorati Reactions Extended
Plugin URI:   http://rick.jinlabs.com/code/dashboard-technorati-reactions-extended
Description:  Displays technorati reactions on your WordPress 2.7+ dashboard.
Version:      2.1.1
Author:       Ricardo Gonz&aacute;lez Castro
Author URI:   http://rick.jinlabs.com/

**************************************************************************/


/***************************************************************************

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
The license is also available at http://www.gnu.org/copyleft/gpl.html

**************************************************************************/

include_once(ABSPATH . WPINC . '/rss.php');

//define('MAGPIE_CACHE_AGE', 120);
//define('MAGPIE_CACHE_ON', 0); //2.7 Cache Bug
//define('MAGPIE_INPUT_ENCODING', 'UTF-8');

/**
 * Content of Dashboard-Widget
 */
function DashboardTechnoratiReactionsExtended() {
					
		$tech_rss_feed = 'http://feeds.technorati.com/cosmos/rss/?url='. trailingslashit(get_option('home')) .'&partner=wordpress';
    
    $widget_options = DashboardTechnoratiReactionsExtended_Options();
   
    $rss = fetch_rss($tech_rss_feed);

		if ( !empty($rss->items) ) {
			echo '<ul id="dashboard-technorati-reactions-extended-list">';
			$rss->items = array_slice($rss->items, 0, $widget_options['items']);
      foreach ($rss->items as $item ) {
      
        $trlink = '<a href="' . wp_filter_kses($item['link']) . '">' . wptexturize(wp_specialchars($item['title'])) . '</a>';

        if($widget_options['showURL']) {
       		$url = parse_url(wp_filter_kses($item['link']));
	        $trlink .=  " &#8212; [".$url['host']."]";
         }
                 
        if($widget_options['showtime']) {				
          $time = strtotime($item['tapi']['linkcreated']);

          if ( ( abs(time() - $time) ) < 86400 )
            $h_time = sprintf( __('%s ago'), human_time_diff( $time ) );
          else
            $h_time = date(__('Y/m/d'), $time);

          $trlink .= sprintf( __(' &#8212; %s', 'dashboard-technorati-reactions-extended'),'<abbr title="' . date(__('Y/m/d H:i:s'), $time) . '">' . $h_time . '</abbr>' );
         }

        if($widget_options['showexcerpt']) {
	        $trlink .=  "<br />[".$item['description']."]";
         }
                
         echo '<li class="trlink">';
         echo $trlink;
         echo '</li>'; 
      }


			echo '				</ul>';
		} else {
				echo '				<p>' . __( 'This dashboard widget queries <a href="http://www.technorati.com/search/">Technorati Search</a> so that when another blog links to your site it will show up here. It has found no incoming links... yet. It\'s okay - there is no rush.', 'dashboard-technorati-reactions-extended' ) . "</p>";
		}
		echo '<p class="textright"><a class="button" href="http://technorati.com/blogs/'.trailingslashit(get_option('home')).'?reactions">'.__('View all').'</a></p>';
		
}
 
/**
 * add Dashboard Widget via function wp_add_dashboard_widget()
 */
function DashboardTechnoratiReactionsExtended_Init() {
	wp_add_dashboard_widget( 'DashboardTechnoratiReactionsExtended', __( 'Dashboard: Technorati Reactions Extended' ), 'DashboardTechnoratiReactionsExtended', 'DashboardTechnoratiReactionsExtended_Setup');
}

function DashboardTechnoratiReactionsExtended_Options() {
	$defaults = array( 'items' => 5, 'showtime' => 1, 'showURL' => 1, 'showexcerpt' => 1);
	if ( ( !$options = get_option( 'DashboardTechnoratiReactionsExtended' ) ) || !is_array($options) )
		$options = array();
	return array_merge( $defaults, $options );
}

function DashboardTechnoratiReactionsExtended_Setup() {

	$options = DashboardTechnoratiReactionsExtended_Options();


	if ( 'post' == strtolower($_SERVER['REQUEST_METHOD']) && isset( $_POST['widget_id'] ) && 'DashboardTechnoratiReactionsExtended' == $_POST['widget_id'] ) {
		foreach ( array( 'items', 'showtime', 'showurl', 'showexcerpt' ) as $key )
				$options[$key] = $_POST[$key];
		update_option( 'DashboardTechnoratiReactionsExtended', $options );
	}
		
?>
	<p>
		<label for="items"><?php _e('How many technorati reactions would you like to display?', 'dashboard-technorati-reactions-extended' ); ?>
			<select id="items" name="items">
				<?php
					for ( $i = 5; $i <= 20; $i = $i + 1 )
						echo "<option value='$i'" . ( $options['items'] == $i ? " selected='selected'" : '' ) . ">$i</option>";
				?>
			</select>
		</label>
	</p>

   <p>
		<label for="showURL">
			<input id="showURL" name="showURL" type="checkbox" value="1"<?php if ( 1 == $options['showURL'] ) echo ' checked="checked"'; ?> />
			<?php _e('Show URL?', 'dashboard-technorati-reactions-extended' ); ?>
		</label>
	</p>
	
   <p>
		<label for="showtime">
			<input id="showtime" name="showtime" type="checkbox" value="1"<?php if ( 1 == $options['showtime'] ) echo ' checked="checked"'; ?> />
			<?php _e('Show reaction date?', 'dashboard-technorati-reactions-extended' ); ?>
		</label>
	</p>
	
   <p>
		<label for="showexcerpt">
			<input id="showexcerpt" name="showexcerpt" type="checkbox" value="1"<?php if ( 1 == $options['showexcerpt'] ) echo ' checked="checked"'; ?> />
			<?php _e('Show excerpt?', 'dashboard-technorati-reactions-extended' ); ?>
		</label>
	</p>	
<?PHP
 }
 
/**
 * use hook, to integrate new widget
 */
add_action('wp_dashboard_setup', 'DashboardTechnoratiReactionsExtended_Init');

?>